/**
 *
 *  BibSonomy-Rest-Client - The REST-client.
 *
 *  Copyright (C) 2006 - 2013 Knowledge & Data Engineering Group,
 *                            University of Kassel, Germany
 *                            http://www.kde.cs.uni-kassel.de/
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package org.bibsonomy.rest.client.queries.get;

import org.bibsonomy.model.Group;
import org.bibsonomy.rest.RESTConfig;
import org.bibsonomy.rest.client.AbstractQuery;
import org.bibsonomy.rest.exceptions.BadRequestOrResponseException;
import org.bibsonomy.rest.exceptions.ErrorPerformingRequestException;

/**
 * Use this Class to receive details about an group of bibsonomy.
 * 
 * @author Manuel Bork <manuel.bork@uni-kassel.de>
 * @version $Id: GetGroupDetailsQuery.java,v 1.19 2013-03-27 13:17:22 bibsonomy Exp $
 */
public final class GetGroupDetailsQuery extends AbstractQuery<Group> {

	private final String groupname;

	/**
	 * Gets details of a group.
	 * 
	 * @param groupname
	 *            name of the user
	 * @throws IllegalArgumentException
	 *             if groupname is null or empty
	 */
	public GetGroupDetailsQuery(final String groupname) throws IllegalArgumentException {
		if (groupname == null || groupname.length() == 0) throw new IllegalArgumentException("no groupname given");

		this.groupname = groupname;
	}

	@Override
	public Group getResult() throws BadRequestOrResponseException, IllegalStateException {
		if (this.downloadedDocument == null) throw new IllegalStateException("Execute the query first.");
		return this.getRenderer().parseGroup(this.downloadedDocument);
	}

	@Override
	protected Group doExecute() throws ErrorPerformingRequestException {
		this.downloadedDocument = performGetRequest(RESTConfig.GROUPS_URL + "/" + this.groupname);
		return null;
	}
}